/*
 * @Author: OBKoro1
 * @Date: 2022-05-17 15:32:44
 * @LastEditors: OBKoro1
 * @LastEditTime: 2022-05-19 10:09:54
 * @Description:
 */
import axios from 'axios';
import VueCookie from 'vue-cookie';
import { message } from 'ant-design-vue';
import store from '@/store';
import { getToken, logout } from '@/utils';

const instance = axios.create({
  // baseURL: 'http://192.168.0.104/api',
  baseURL: '/api',
  timeout: 10 * 60 * 1000,
});

const requestHandlers = [(config) => {
  const token = getToken();
  if (token != null) {
    config.headers.authorization = token;
    config.headers.type = 'unioncenter'; // 类型 商户
  }
  return config;
}, err => Promise.reject(err)];

const responseHandlers = [(response) => {
  // response.data = { code: '401', msg: 'token错误' };
  if (response.data instanceof ArrayBuffer || typeof response.data === 'string' || response.data instanceof Blob) {
    // 处理文件下载
    return response;
  }
  const responseCode = Number(response.data.code);
  if (responseCode !== 200 && responseCode !== 401) {
    if (response.data && response.data.code === 'at_001') {
      return Promise.reject(response.data);
    }
    const error = response.data.message || response.data.msg || '后台服务出现错误';
    message.error(error);
    return Promise.reject(new Error(`${error}, 错误码: ${response.data.code}`)); // 这里会可能返回特殊的code
  }
  if (responseCode === 401) {
    logout(VueCookie, store);
    return Promise.reject();
  }
  return response.data.data;
},
(error) => {
  if (error.response) {
    if (error.response.status === 401) {
      logout(VueCookie, store);
      return Promise.reject();
    }
  }
  return Promise.reject(error);
},
];

instance.interceptors.request.use(...requestHandlers);

instance.interceptors.response.use(...responseHandlers);

export default instance;
